You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2019/10/22 19:47:00 UTC

[commons-collections] branch master updated: [COLLECTIONS-704] Update size to capacity for GrowthList (#90)

This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-collections.git


The following commit(s) were added to refs/heads/master by this push:
     new c184745  [COLLECTIONS-704] Update size to capacity for GrowthList (#90)
c184745 is described below

commit c184745990c576343870f4a9371092683f5ea486
Author: dota17 <50...@users.noreply.github.com>
AuthorDate: Wed Oct 23 03:46:53 2019 +0800

    [COLLECTIONS-704] Update size to capacity for GrowthList (#90)
---
 .../java/org/apache/commons/collections4/list/GrowthList.java     | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/main/java/org/apache/commons/collections4/list/GrowthList.java b/src/main/java/org/apache/commons/collections4/list/GrowthList.java
index efe0525..79d28d1 100644
--- a/src/main/java/org/apache/commons/collections4/list/GrowthList.java
+++ b/src/main/java/org/apache/commons/collections4/list/GrowthList.java
@@ -86,11 +86,11 @@ public class GrowthList<E> extends AbstractSerializableListDecorator<E> {
     /**
      * Constructor that uses an ArrayList internally.
      *
      * @param initialSize  the initial size of the ArrayList
      * @throws IllegalArgumentException if initial size is invalid
      */
-    public GrowthList(final int initialSize) {
-        super(new ArrayList<E>(initialSize));
+    public GrowthList(final int initialCapacity) {
+        super(new ArrayList<E>(initialCapacity));
     }
 
     /**
@@ -86,11 +86,11 @@ public class GrowthList<E> extends AbstractSerializableListDecorator<E> {
      * Constructor that uses an ArrayList internally.
      *
-     * @param initialSize  the initial size of the ArrayList
-     * @throws IllegalArgumentException if initial size is invalid
+     * @param initialCapacity  the initial capacity of the ArrayList
+     * @throws IllegalArgumentException if initial capacity is invalid
      */